@@ -62,7 +62,7 @@ class AppendOperator(AstroSQLBaseOperator):
         )
 
     def execute(self, context: Context) -> BaseTable:  # skipcq: PYL-W0613
-        db = create_database(self.target_table.conn_id)
+        db = create_database(self.target_table.conn_id, table=self.source_table)
         self.source_table = db.populate_table_metadata(self.source_table)
         self.target_table = db.populate_table_metadata(self.target_table)
         db.append_table(
@@ -79,62 +79,66 @@ class AppendOperator(AstroSQLBaseOperator):
         """
         append_query = task_instance.xcom_pull(task_ids=task_instance.task_id, key="append_query")
         source_table_rows = self.source_table.row_count
-        input_uri = (
-            f"{self.source_table.openlineage_dataset_namespace()}"
-            f"://{self.source_table.openlineage_dataset_name()}"
-        )
-        input_dataset: list[OpenlineageDataset] = [
-            OpenlineageDataset(
-                namespace=self.source_table.openlineage_dataset_namespace(),
-                name=self.source_table.openlineage_dataset_name(),
-                facets={
-                    "input_table_facet": TableDatasetFacet(
-                        table_name=self.source_table.name,
-                        source_table_rows=source_table_rows,
-                        columns=self.columns,
-                        metadata=self.source_table.metadata,
-                    ),
-                    "schema": SchemaDatasetFacet(
-                        fields=[
-                            SchemaField(
-                                name=self.source_table.metadata.schema,
-                                type=self.source_table.metadata.database,
-                            )
-                        ]
-                    ),
-                    "dataSource": DataSourceDatasetFacet(name=self.source_table.name, uri=input_uri),
-                    "dataQualityMetrics": DataQualityMetricsInputDatasetFacet(
-                        rowCount=self.source_table.row_count, columnMetrics={}
-                    ),
-                },
+        input_dataset: list[OpenlineageDataset] = [OpenlineageDataset(namespace=None, name=None, facets={})]
+        output_dataset: list[OpenlineageDataset] = [OpenlineageDataset(namespace=None, name=None, facets={})]
+        if self.source_table.openlineage_emit_temp_table_event():
+            input_uri = (
+                f"{self.source_table.openlineage_dataset_namespace()}"
+                f"://{self.source_table.openlineage_dataset_name()}"
             )
-        ]
+            input_dataset = [
+                OpenlineageDataset(
+                    namespace=self.source_table.openlineage_dataset_namespace(),
+                    name=self.source_table.openlineage_dataset_name(),
+                    facets={
+                        "input_table_facet": TableDatasetFacet(
+                            table_name=self.source_table.name,
+                            source_table_rows=source_table_rows,
+                            columns=self.columns,
+                            metadata=self.source_table.metadata,
+                        ),
+                        "schema": SchemaDatasetFacet(
+                            fields=[
+                                SchemaField(
+                                    name=self.source_table.metadata.schema,
+                                    type=self.source_table.metadata.database,
+                                )
+                            ]
+                        ),
+                        "dataSource": DataSourceDatasetFacet(name=self.source_table.name, uri=input_uri),
+                        "dataQualityMetrics": DataQualityMetricsInputDatasetFacet(
+                            rowCount=self.source_table.row_count, columnMetrics={}
+                        ),
+                    },
+                )
+            ]
 
-        output_uri = (
-            f"{self.target_table.openlineage_dataset_namespace()}"
-            f"://{self.target_table.openlineage_dataset_name()}"
-        )
-        output_dataset: list[OpenlineageDataset] = [
-            OpenlineageDataset(
-                namespace=self.target_table.openlineage_dataset_namespace(),
-                name=self.target_table.openlineage_dataset_name(),
-                facets={
-                    "output_table_facet": TableDatasetFacet(
-                        table_name=self.target_table.name,
-                        columns=self.columns,
-                        source_table_rows=source_table_rows,
-                        metadata=self.target_table.metadata,
-                    ),
-                    "outputStatistics": OutputStatisticsOutputDatasetFacet(
-                        rowCount=self.target_table.row_count
-                    ),
-                    "dataSource": DataSourceDatasetFacet(name=self.target_table.name, uri=output_uri),
-                    "dataQualityMetrics": DataQualityMetricsInputDatasetFacet(
-                        rowCount=self.target_table.row_count, columnMetrics={}
-                    ),
-                },
+        if self.source_table.openlineage_emit_temp_table_event():
+            output_uri = (
+                f"{self.target_table.openlineage_dataset_namespace()}"
+                f"://{self.target_table.openlineage_dataset_name()}"
             )
-        ]
+            output_dataset = [
+                OpenlineageDataset(
+                    namespace=self.target_table.openlineage_dataset_namespace(),
+                    name=self.target_table.openlineage_dataset_name(),
+                    facets={
+                        "output_table_facet": TableDatasetFacet(
+                            table_name=self.target_table.name,
+                            columns=self.columns,
+                            source_table_rows=source_table_rows,
+                            metadata=self.target_table.metadata,
+                        ),
+                        "outputStatistics": OutputStatisticsOutputDatasetFacet(
+                            rowCount=self.target_table.row_count
+                        ),
+                        "dataSource": DataSourceDatasetFacet(name=self.target_table.name, uri=output_uri),
+                        "dataQualityMetrics": DataQualityMetricsInputDatasetFacet(
+                            rowCount=self.target_table.row_count, columnMetrics={}
+                        ),
+                    },
+                )
+            ]
 
         run_facets: dict[str, BaseFacet] = {}
         job_facets: dict[str, BaseFacet] = {"sql": SqlJobFacet(query=str(append_query))}
